@@ -1,18 +1,28 @@
+var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };
+
 import React, { PropTypes } from 'react';
-import PanelPropertiesEditor from './panel-properties-editor/panel-properties-editor';
+import PanelElementEditor from './panel-element-editor/panel-element-editor';
 import PanelLayers from './panel-layers';
 import PanelGuides from './panel-guides';
 import PanelLayerElements from './panel-layer-elements';
 
+var STYLE = {
+  backgroundColor: "#28292D",
+  display: "block",
+  overflowY: "auto",
+  overflowX: "hidden"
+};
+
 export default function Sidebar(_ref) {
-  var width = _ref.width,
-      height = _ref.height,
-      state = _ref.state;
+  var state = _ref.state,
+      width = _ref.width,
+      height = _ref.height;
+
 
   return React.createElement(
     'aside',
     {
-      style: { backgroundColor: "#28292D", display: "block", overflow: "scroll", width: width, height: height },
+      style: _extends({ width: width, height: height }, STYLE),
       onKeyDown: function onKeyDown(event) {
         return event.stopPropagation();
       },
@@ -21,6 +31,11 @@ export default function Sidebar(_ref) {
       },
       className: 'sidebar'
     },
+    React.createElement(
+      'div',
+      { className: 'layers' },
+      React.createElement(PanelLayers, { state: state })
+    ),
     React.createElement(
       'div',
       { className: 'layer-elements' },
@@ -29,18 +44,13 @@ export default function Sidebar(_ref) {
     React.createElement(
       'div',
       { className: 'properties' },
-      React.createElement(PanelPropertiesEditor, { state: state })
-    ),
-    React.createElement(
-      'div',
-      { className: 'layers' },
-      React.createElement(PanelLayers, { state: state })
+      React.createElement(PanelElementEditor, { state: state })
     )
   );
 }
 
 Sidebar.propTypes = {
-  width: PropTypes.number.isRequired,
-  height: PropTypes.number.isRequired,
-  state: PropTypes.object.isRequired
+  state: PropTypes.object.isRequired,
+  width: React.PropTypes.number.isRequired,
+  height: React.PropTypes.number.isRequired
 };
\ No newline at end of file
