@@ -1,17 +1,42 @@
+/** @description Determines the distance between two points
+ *  @param {number} x0 Vertex 0 x
+ *  @param {number} y0 Vertex 0 y
+ *  @param {number} x1 Vertex 1 x
+ *  @param {number} y1 Vertex 1 y
+ *  @return {number}
+ */
+import {toFixedFloat, fAbs} from './math.js';
+import {EPSILON} from "../constants";
+
 export function compareVertices(v0, v1) {
   return v0.x === v1.x ? v0.y - v1.y : v0.x - v1.x
 }
 
-export function minVertex(v0,v1) {
-  return compareVertices(v0,v1) > 0 ? v1: v0;
+export function minVertex(v0, v1) {
+  return compareVertices(v0, v1) > 0 ? v1 : v0;
 }
 
-export function maxVertex(v0,v1) {
-  return compareVertices(v0,v1) > 0 ? v0: v1;
+export function maxVertex(v0, v1) {
+  return compareVertices(v0, v1) > 0 ? v0 : v1;
 }
 
-export function distanceFromTwoPoints(x0, y0, x1, y1) {
-  return Math.sqrt(Math.pow((x1 - x0), 2) + Math.pow((y1 - y0), 2));
+export function orderVertices(vertices) {
+  return vertices.sort(compareVertices);
+}
+
+export function pointsDistance(x0, y0, x1, y1) {
+  let diff_x = x0 - x1;
+  let diff_y = y0 - y1;
+
+  return Math.sqrt((diff_x * diff_x) + (diff_y * diff_y));
+}
+
+export function verticesDistance(v1, v2) {
+
+  let {x: x0, y: y0} = v1;
+  let {x: x1, y: y1} = v2;
+
+  return pointsDistance(x0, y0, x1, y1);
 }
 
 export function horizontalLine(y) {
@@ -39,7 +64,7 @@ export function linePassingThroughTwoPoints(x1, y1, x2, y2) {
 
 export function distancePointFromLine(a, b, c, x, y) {
   //https://en.wikipedia.org/wiki/Distance_from_a_point_to_a_line
-  return Math.abs(a * x + b * y + c) / Math.sqrt(a * a + b * b);
+  return fAbs(a * x + b * y + c) / Math.sqrt(a * a + b * b);
 }
 
 export function closestPointFromLine(a, b, c, x, y) {
@@ -47,7 +72,7 @@ export function closestPointFromLine(a, b, c, x, y) {
   let denom = a * a + b * b;
   return {
     x: (b * (b * x - a * y) - a * c) / denom,
-    y: ((a * -b * x + a * y ) - b * c) / denom,
+    y: ((a * -b * x + a * y) - b * c) / denom,
   }
 }
 
@@ -67,7 +92,7 @@ export function intersectionFromTwoLineSegment(p1, p2, p3, p4) {
   let {x: x1, y: y1} = p1;
   let {x: x2, y: y2} = p2;
   let {x: x3, y: y3} = p3;
-  let {x: x4, y:y4} = p4;
+  let {x: x4, y: y4} = p4;
 
   let EPSILON = 10e-6;
 
@@ -75,8 +100,8 @@ export function intersectionFromTwoLineSegment(p1, p2, p3, p4) {
   let numA = ((x4 - x3) * (y1 - y3)) - ((y4 - y3) * (x1 - x3));
   let numB = ((x2 - x1) * (y1 - y3)) - ((y2 - y1) * (x1 - x3));
 
-  if (Math.abs(denom) <= EPSILON) {
-    if (Math.abs(numA) <= EPSILON && Math.abs(numB) <= EPSILON) {
+  if (fAbs(denom) <= EPSILON) {
+    if (fAbs(numA) <= EPSILON && fAbs(numB) <= EPSILON) {
 
       let comparator = (pa, pb) => pa.x === pb.x ? pa.y - pb.y : pa.x - pb.x;
       let line0 = [p1, p2].sort(comparator);
@@ -141,6 +166,21 @@ export function distancePointFromLineSegment(x1, y1, x2, y2, xp, yp) {
   return Math.sqrt(dx * dx + dy * dy);
 }
 
+/**
+ *
+ * @param x1 {number} x for first vertex of the segment
+ * @param y1 {number} y for first vertex of the segment
+ * @param x2 {number} x for second vertex of the segment
+ * @param y2 {number} y for second vertex of the segment
+ * @param xp {number} x for point we want to verify
+ * @param yp {number} y for point we want to verify
+ * @param maxDistance {number} the epsilon value used for comparisons
+ * @returns {boolean} true if the point lies on the line segment false otherwise
+ */
+export function isPointOnLineSegment(x1, y1, x2, y2, xp, yp, maxDistance = EPSILON) {
+  return distancePointFromLineSegment(x1, y1, x2, y2, xp, yp) <= maxDistance;
+}
+
 export function closestPointFromLineSegment(x1, y1, x2, y2, xp, yp) {
   if (x1 === x2) return {x: x1, y: yp};
   if (y1 === y2) return {x: xp, y: y1};
@@ -158,8 +198,8 @@ export function closestPointFromLineSegment(x1, y1, x2, y2, xp, yp) {
 }
 
 export function pointPositionOnLineSegment(x1, y1, x2, y2, xp, yp) {
-  let length = distanceFromTwoPoints(x1, y1, x2, y2);
-  let distance = distanceFromTwoPoints(x1, y1, xp, yp);
+  let length = pointsDistance(x1, y1, x2, y2);
+  let distance = pointsDistance(x1, y1, xp, yp);
 
   let offset = distance / length;
   if (x1 > x2) offset = mapRange(offset, 0, 1, 1, 0);
@@ -172,11 +212,34 @@ export function mapRange(value, low1, high1, low2, high2) {
 }
 
 export function angleBetweenTwoPointsAndOrigin(x1, y1, x2, y2) {
-  let length = distanceFromTwoPoints(x1, y1, x2, y2);
-  return (-Math.asin((y1 - y2) / length)) * 180 / Math.PI;
+  return -(Math.atan2(y1 - y2, x2-x1)) * 180 / Math.PI;
 }
 
-export function samePoints({x:x1, y:y1}, {x:x2, y:y2}) {
+export function samePoints({x: x1, y: y1}, {x: x2, y: y2}) {
   let EPSILON = 10e-6;
-  return Math.abs(x1 - x2) <= EPSILON && Math.abs(y1 - y2) <= EPSILON;
+  return fAbs(x1 - x2) <= EPSILON && fAbs(y1 - y2) <= EPSILON;
+}
+
+/** @description Extend line based on coordinates and new line length
+ *  @param {number} x1 Vertex 1 x
+ *  @param {number} y1 Vertex 1 y
+ *  @param {number} x2 Vertex 2 x
+ *  @param {number} y2 Vertex 2 y
+ *  @param {number} newDistance New line length
+ *  @return {object}
+ */
+export function extendLine(x1, y1, x2, y2, newDistance, precision = 6) {
+  let rad = Math.atan2(y2 - y1, x2 - x1);
+
+  return {
+    x: toFixedFloat(x1 + (Math.cos(rad) * newDistance), precision),
+    y: toFixedFloat(y1 + (Math.sin(rad) * newDistance), precision),
+  }
+}
+
+export function roundVertex(vertex, precision = 6) {
+  vertex.set('x', toFixedFloat(vertex.get('x'), precision));
+  vertex.set('y', toFixedFloat(vertex.get('y'), precision));
+
+  return vertex;
 }
